@@ -11,7 +11,7 @@ from __future__ import annotations
 import asyncio
 import logging
 
-from typing import Any, Callable, Optional
+from typing import Any, Callable, List, Optional
 
 from clu.base import BaseClient
 from clu.command import Command, CommandStatus
@@ -35,7 +35,7 @@ class TronKey(Property):
     def __init__(
         self,
         name: str,
-        value: list[Any] = [],
+        value: List[Any] = [],
         key: Optional[str] = None,
         model: Optional[TronModel] = None,
         callback: Optional[Callable[[TronKey], Any]] = None,
@@ -45,6 +45,9 @@ class TronKey(Property):
 
         self.key = key
 
+    def __getitem__(self, sl):
+        return self.value.__getitem__(sl)
+
 
 class TronModel(BaseModel[TronKey]):
     """A JSON-compliant model for actor keywords.
@@ -55,9 +58,8 @@ class TronModel(BaseModel[TronKey]):
         A dictionary of keys that define the datamodel.
     callback
         A function or coroutine to call when the datamodel changes. The
-        function is called with the instance of `.TronModel` and the
-        `.TronKey` that has changed. If the callback is a coroutine,
-        it is scheduled as a task.
+        function is called with the instance of `.TronModel` and the modified keyword.
+        If the callback is a coroutine, it is scheduled as a task.
     log
         Where to log messages.
     """
@@ -100,7 +102,17 @@ class TronModel(BaseModel[TronKey]):
             self[key_name].value = [value.native for value in reply_key.values]
             self[key_name].key = reply_key
 
-            self.notify(self)
+            loop = asyncio.get_event_loop()
+            print(loop)
+
+            self.notify(self, self[key_name])
+
+
+class TronLoggingFilter(logging.Filter):
+    """Logs issues with the Tron parser only to the file logger."""
+
+    def filter(self, record):
+        return not record.getMessage().startswith("Failed parsing reply")
 
 
 class TronConnection(BaseClient):
@@ -125,7 +137,7 @@ class TronConnection(BaseClient):
         host: str,
         port: int = 6093,
         name: str = "tron",
-        models: list[str] = [],
+        models: List[str] = [],
         **kwargs,
     ):
 
@@ -150,6 +162,10 @@ class TronConnection(BaseClient):
         self._client = None
         self.running_commands = {}
 
+        # We want to log problems with the Tron parser, but not to the console.
+        if self.log.sh:
+            self.log.sh.addFilter(TronLoggingFilter())
+
     async def start(self, get_keys=True):
         """Starts the connection to Tron.
 
@@ -277,7 +293,7 @@ class TronConnection(BaseClient):
                     self.models[actor].parse_reply(reply)
                 except ParseError as ee:
                     self.log.warning(
-                        f"Failed parsing reply {reply!r} " f"with error: {ee!s}"
+                        f"Failed parsing reply {reply!r} with error: {ee!s}"
                     )
 
             mid = reply.header.commandId
