@@ -4,6 +4,8 @@ Message classes for SDSS-3 command and reply protocols
 Refer to https://trac.sdss3.org/wiki/Ops/Messages for details.
 """
 
+# type: ignore
+
 # Created 10-Oct-2008 by David Kirkby (dkirkby@uci.edu)
 
 import re
@@ -55,10 +57,10 @@ class Values(list, Canonized):
         white space. A single value is always quoted. A canonical string
         is, by definition, invariant under parsing.
         """
-        result = ''
+        result = ""
         for (comma, value) in enumerate(self):
             if comma:
-                result += ','
+                result += ","
             if isinstance(value, float):
                 # use repr to capture the full precision
                 value = repr(float(value))
@@ -69,7 +71,7 @@ class Values(list, Canonized):
                 result += value
             else:
                 # only double quotes need to be escaped
-                result += '"%s"' % value.decode('string_escape').replace('"', '\\"')
+                result += '"%s"' % value.decode("string_escape").replace('"', '\\"')
         return result
 
     def tokenized(self):
@@ -80,11 +82,11 @@ class Values(list, Canonized):
         keyword. Does not distinguish between quoted and unquoted
         values. A tokenized string is invariant under parsing.
         """
-        result = ''
+        result = ""
         for (comma, value) in enumerate(self):
             if comma:
-                result += ','
-            result += '123'
+                result += ","
+            result += "123"
         return result
 
 
@@ -101,7 +103,7 @@ class Keyword(Canonized):
         not be used. No checks are performed on the characters used in
         the name (the parser has normally already done this).
         """
-        if name.lower() == 'raw':
+        if name.lower() == "raw":
             raise MessageError('keyword "%s" is reserved' % name)
         self.name = name
         self.values = Values(values or [])
@@ -117,7 +119,7 @@ class Keyword(Canonized):
         """
         result = self.name.lower()
         if self.values and len(self.values) > 0:
-            result += '=%s' % self.values.canonical()
+            result += "=%s" % self.values.canonical()
         return result
 
     def tokenized(self):
@@ -127,9 +129,9 @@ class Keyword(Canonized):
         Two keywords with identical tokenized strings have the same
         basic grammar. A tokenized string is invariant under parsing.
         """
-        result = 'KEY'
+        result = "KEY"
         if self.values and len(self.values) > 0:
-            result += '=%s' % self.values.tokenized()
+            result += "=%s" % self.values.tokenized()
         return result
 
     def clone(self):
@@ -149,9 +151,9 @@ class Keyword(Canonized):
         self.matched = other.matched
 
     def __repr__(self):
-        result = 'KEY(%s)=%r' % (self.name, self.values)
+        result = "KEY(%s)=%r" % (self.name, self.values)
         if self.matched:
-            result = '{' + result + '}'
+            result = "{" + result + "}"
         return result
 
     def __getitem__(self, ii):
@@ -174,25 +176,25 @@ class RawKeyword(Keyword):
         """
         Creates a new raw keyword instance
         """
-        self.name = 'raw'
+        self.name = "raw"
         self.values = Values([line])
         self.matched = False
 
     def __repr__(self):
-        result = 'RAWKEY(%s)=%r' % (self.name, self.values)
+        result = "RAWKEY(%s)=%r" % (self.name, self.values)
         return result
 
     def canonical(self):
         """
         Returns the canonical string representation of a raw keyword
         """
-        return 'raw=%s' % self.values[0]
+        return "raw=%s" % self.values[0]
 
     def tokenized(self):
         """
         Returns the parse token representation of a raw keyword
         """
-        return 'RAW=LINE'
+        return "RAW=LINE"
 
     def clone(self):
         """
@@ -223,7 +225,7 @@ class Keywords(list, Canonized):
         equivalent. Keyword ordering is considered to be significant. A
         canonical string is, by definition, invariant under parsing.
         """
-        result = ''
+        result = ""
         for delimited, keyword in enumerate(self):
             if delimited:
                 result += delimiter
@@ -238,7 +240,7 @@ class Keywords(list, Canonized):
         same basic grammar. Keyword ordering is considered to be
         significant. A tokenized string is invariant under parsing.
         """
-        result = ''
+        result = ""
         for delimited, keyword in enumerate(self):
             if delimited:
                 result += delimiter
@@ -277,7 +279,7 @@ class Keywords(list, Canonized):
                     if k.name.lower() == name:
                         return k
                 raise KeyError(index)
-            raise TypeError('Keywords index must be integer or string')
+            raise TypeError("Keywords index must be integer or string")
 
     def get(self, name, default=None):
         """Returns the keyword matching name or default if not found."""
@@ -304,27 +306,36 @@ class Keywords(list, Canonized):
                 if k.name.lower() == lower:
                     return True
             return False
-        raise TypeError('Keyword names must be strings')
+        raise TypeError("Keyword names must be strings")
 
 
 class ReplyHeader(Canonized):
     """
     Represents the headers of a reply
     """
+
     MsgCode = types.Enum(
-        '>',
-        'D',
-        'I',
-        'W',
-        'E',
-        ':',
-        'F',
-        '!',
+        ">",
+        "D",
+        "I",
+        "W",
+        "E",
+        ":",
+        "F",
+        "!",
         labelHelp=[
-            'Queued', 'Debug', 'Information', 'Warning', 'Error', 'Finished', 'Error', 'Fatal'
+            "Queued",
+            "Debug",
+            "Information",
+            "Warning",
+            "Error",
+            "Finished",
+            "Error",
+            "Fatal",
         ],
-        name='code',
-        help='Reply header status code')
+        name="code",
+        help="Reply header status code",
+    )
 
     def __init__(self, program, user, actorStack, commandId, actor, code):
         self.program = program
@@ -332,22 +343,24 @@ class ReplyHeader(Canonized):
         self.actorStack = actorStack
         # The commander name is the concatenation of the first three fields and should
         # exactly reproduce the initial word of the reply message string.
-        self.cmdrName = '%s.%s%s' % (self.program, self.user, self.actorStack)
+        self.cmdrName = "%s.%s%s" % (self.program, self.user, self.actorStack)
         self.commandId = int(commandId)
         self.actor = actor
         try:
             self.code = ReplyHeader.MsgCode(code)
         except ValueError:
-            raise MessageError('Invalid reply header code: %s' % code)
+            raise MessageError("Invalid reply header code: %s" % code)
 
     def canonical(self):
-        return '%s %d %s %s' % (self.cmdrName, self.commandId, self.actor, self.code)
+        return "%s %d %s %s" % (self.cmdrName, self.commandId, self.actor, self.code)
 
     def tokenized(self):
-        return 'prog.user 123 actor %s' % self.code
+        return "prog.user 123 actor %s" % self.code
 
     def clone(self):
-        return ReplyHeader(self.program, self.user, self.commandId, self.actor, self.code)
+        return ReplyHeader(
+            self.program, self.user, self.commandId, self.actor, self.code
+        )
 
     def copy(self, other):
         self.program = other.program
@@ -357,28 +370,42 @@ class ReplyHeader(Canonized):
         self.code = other.code
 
     def __repr__(self):
-        return 'HDR(%s,%s,%d,%s,%s)' % (self.program, self.user, self.commandId, self.actor,
-                                        self.code)
+        return "HDR(%s,%s,%d,%s,%s)" % (
+            self.program,
+            self.user,
+            self.commandId,
+            self.actor,
+            self.code,
+        )
 
 
 class ActorReplyHeader(Canonized):
     """
     Represents the header of a reply from an actor (as opposed to the hub)
     """
+
     MsgCode = types.Enum(
-        '>',
-        'D',
-        'I',
-        'W',
-        'E',
-        ':',
-        'F',
-        '!',
+        ">",
+        "D",
+        "I",
+        "W",
+        "E",
+        ":",
+        "F",
+        "!",
         labelHelp=[
-            'Queued', 'Debug', 'Information', 'Warning', 'Error', 'Finished', 'Error', 'Fatal'
+            "Queued",
+            "Debug",
+            "Information",
+            "Warning",
+            "Error",
+            "Finished",
+            "Error",
+            "Fatal",
         ],
-        name='code',
-        help='Reply header status code')
+        name="code",
+        help="Reply header status code",
+    )
 
     def __init__(self, commandId, userId, code):
         self.commandId = int(commandId)
@@ -386,13 +413,13 @@ class ActorReplyHeader(Canonized):
         try:
             self.code = ReplyHeader.MsgCode(code)
         except ValueError:
-            raise MessageError('Invalid reply header code: %s' % code)
+            raise MessageError("Invalid reply header code: %s" % code)
 
     def canonical(self):
-        return '%d %d %s' % (self.commandId, self.userId, self.code)
+        return "%d %d %s" % (self.commandId, self.userId, self.code)
 
     def tokenized(self):
-        return '123 1 %s' % self.code
+        return "123 1 %s" % self.code
 
     def clone(self):
         return ReplyHeader(self.commandId, self.userId, self.code)
@@ -403,7 +430,7 @@ class ActorReplyHeader(Canonized):
         self.code = other.code
 
     def __repr__(self):
-        return 'ACTHDR(%d,%d,%s)' % (self.commandId, self.userId, self.code)
+        return "ACTHDR(%d,%d,%s)" % (self.commandId, self.userId, self.code)
 
 
 class Reply(Canonized):
@@ -430,7 +457,10 @@ class Reply(Canonized):
         Two replies with identical canonical strings are equivalent. A
         canonical string is, by definition, invariant under parsing.
         """
-        return '%s %s' % (self.header.canonical(), self.keywords.canonical(delimiter=';'))
+        return "%s %s" % (
+            self.header.canonical(),
+            self.keywords.canonical(delimiter=";"),
+        )
 
     def tokenized(self):
         """
@@ -439,7 +469,10 @@ class Reply(Canonized):
         Two replies with identical tokenized strings have the same
         basic grammar. A tokenized string is invariant under parsing.
         """
-        return '%s %s' % (self.header.tokenized(), self.keywords.tokenized(delimiter=';'))
+        return "%s %s" % (
+            self.header.tokenized(),
+            self.keywords.tokenized(delimiter=";"),
+        )
 
     def clone(self):
         """
@@ -458,7 +491,7 @@ class Reply(Canonized):
         self.string = other.string
 
     def __repr__(self):
-        result = 'REPLY(%r,%r)' % (self.header, self.keywords)
+        result = "REPLY(%r,%r)" % (self.header, self.keywords)
         return result
 
 
@@ -475,13 +508,13 @@ class CommandHeader(Canonized):
     @property
     def program(self):
         """ Return program part of cmdrname. """
-        return self.cmdrName.split('.', 1)[0]
+        return self.cmdrName.split(".", 1)[0]
 
     def canonical(self):
-        return '%s %d %s' % (self.cmdrName, self.mid, self.actor)
+        return "%s %d %s" % (self.cmdrName, self.mid, self.actor)
 
     def tokenized(self):
-        return 'prog.user 123 actor %s' % self.actor
+        return "prog.user 123 actor %s" % self.actor
 
     def clone(self):
         return CommandHeader(self.cmdrName, self.mid, self.actor)
@@ -492,7 +525,7 @@ class CommandHeader(Canonized):
         self.actor = other.actor
 
     def __repr__(self):
-        return 'CommandHeader(%s,%d,%s)' % (self.cmdrName, self.mid, self.actor)
+        return "CommandHeader(%s,%d,%s)" % (self.cmdrName, self.mid, self.actor)
 
 
 class Command(Canonized):
@@ -512,9 +545,9 @@ class Command(Canonized):
         performed on the characters used in the name (the parser has
         normally already done this).
         """
-        if '.' in name:
-            raise MessageError('name %r contains an illegal dot (.) character.' % name)
-        if name.lower() == 'raw':
+        if "." in name:
+            raise MessageError("name %r contains an illegal dot (.) character." % name)
+        if name.lower() == "raw":
             raise MessageError('name cannot be "%s"' % name)
         self.name = name
         self.values = Values(values or [])
@@ -531,10 +564,10 @@ class Command(Canonized):
         """
         result = self.name.lower()
         if self.values and len(self.values) > 0:
-            result += ' %s' % self.values.canonical()
+            result += " %s" % self.values.canonical()
         if self.keywords:
-            result += ' '
-            result += self.keywords.canonical(delimiter=' ')
+            result += " "
+            result += self.keywords.canonical(delimiter=" ")
         return result
 
     def tokenized(self):
@@ -544,12 +577,12 @@ class Command(Canonized):
         Two commands with identical tokenized strings have the same
         basic grammar. A tokenized string is invariant under parsing.
         """
-        result = 'VERB'
+        result = "VERB"
         if self.values and len(self.values) > 0:
-            result += ' %s' % self.values.tokenized()
+            result += " %s" % self.values.tokenized()
         if self.keywords:
-            result += ' '
-            result += self.keywords.tokenized(delimiter=' ')
+            result += " "
+            result += self.keywords.tokenized(delimiter=" ")
         return result
 
     def clone(self):
@@ -570,5 +603,5 @@ class Command(Canonized):
         self.string = other.string
 
     def __repr__(self):
-        result = 'CMD(%r=%r;%r)' % (self.name, self.values, self.keywords)
+        result = "CMD(%r=%r;%r)" % (self.name, self.values, self.keywords)
         return result
